@@ -654,6 +654,10 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                 cartaporte_mercancia.setAttribute('PesoEnKg', mercancia_data.get('PesoEnKg'))
                 cartaporte_mercancia.setAttribute('ValorMercancia', mercancia_data.get('ValorMercancia'))
                 cartaporte_mercancia.setAttribute('Moneda', mercancia_data.get('Moneda'))
+
+                if mercancia_data.get('MaterialPeligroso') == 'No':
+                    cartaporte_mercancia.setAttribute('MaterialPeligroso', 'No')
+
                 if mercancia_data.get('MaterialPeligroso') == 'Si':
                     cartaporte_mercancia.setAttribute('MaterialPeligroso', mercancia_data.get('MaterialPeligroso'))
                     cartaporte_mercancia.setAttribute('CveMaterialPeligroso', mercancia_data.get('CveMaterialPeligroso'))
@@ -694,12 +698,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
 
                 cartaporte_seguros = self.dom.createElement('cartaporte20:Seguros')
                 cartaporte_seguros.setAttribute('AseguraRespCivil', transporte_data.get('NombreAseg'))
-                cartaporte_seguros.setAttribute('AseguraMedAmbiente', transporte_data.get('NombreAseg'))
-                cartaporte_seguros.setAttribute('AseguraCarga', transporte_data.get('NombreAseg'))
-                cartaporte_seguros.setAttribute('PolizaCarga', transporte_data.get('NumPolizaSeguro'))
-                cartaporte_seguros.setAttribute('PolizaMedAmbiente', transporte_data.get('NumPolizaSeguro'))
                 cartaporte_seguros.setAttribute('PolizaRespCivil', transporte_data.get('NumPolizaSeguro'))
-                cartaporte_seguros.setAttribute('PrimaSeguro', '1000')
 
                 cartaporte_tipo_transporte.appendChild(cartaporte_seguros)
 
@@ -748,6 +747,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                 #     cartaporte_operador.appendChild(cartaporte_operador_domicilio)
 
                 # cartaporte_operadores.appendChild(cartaporte_operador)
+
             # cartaporte_figura_transporte.appendChild(cartaporte_operadores)
             cartaporte_figura_transporte.appendChild(cartaporte_operador)
             cartaporte.appendChild(cartaporte_figura_transporte)
